# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AppliesToEnum(object):

    """Implementation of the 'AppliesTo' enum.

    Which kinds of admins this policy applies to. Can be one of 'All
    organization admins', 'All enterprise admins', 'All network admins', 'All
    admins of networks...', 'All admins of networks tagged...', 'Specific
    admins...', 'All admins' or 'All SAML admins'.

    Attributes:
        ENUM_ALL ORGANIZATION ADMINS: TODO: type description here.
        ENUM_ALL ENTERPRISE ADMINS: TODO: type description here.
        ENUM_ALL NETWORK ADMINS: TODO: type description here.
        ENUM_ALL ADMINS OF NETWORKS: TODO: type description here.
        ENUM_ALL ADMINS OF NETWORKS TAGGED: TODO: type description here.
        ENUM_SPECIFIC ADMINS: TODO: type description here.
        ENUM_ALL ADMINS: TODO: type description here.
        ENUM_ALL SAML ADMINS: TODO: type description here.

    """

    ENUM_ALL_ORGANIZATION_ADMINS = 'All organization admins'

    ENUM_ALL_ENTERPRISE_ADMINS = 'All enterprise admins'

    ENUM_ALL_NETWORK_ADMINS = 'All network admins'

    ENUM_ALL_ADMINS_OF_NETWORKS = 'All admins of networks...'

    ENUM_ALL_ADMINS_OF_NETWORKS_TAGGED = 'All admins of networks tagged...'

    ENUM_SPECIFIC_ADMINS = 'Specific admins...'

    ENUM_ALL_ADMINS = 'All admins'

    ENUM_ALL_SAML_ADMINS = 'All SAML admins'

