# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Settings1Enum(object):

    """Implementation of the 'Settings1' enum.

    How firewall and traffic shaping rules are enforced. Can be 'network
    default', 'ignore' or 'custom'.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        IGNORE: TODO: type description here.
        CUSTOM: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    IGNORE = 'ignore'

    CUSTOM = 'custom'

