# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Mode1Enum(object):

    """Implementation of the 'Mode1' enum.

    The traffic analysis mode for the network. Can be one of 'disabled' (do
    not collect traffic types),
        'basic' (collect generic traffic categories), or 'detailed' (collect
        destination hostnames).

    Attributes:
        DISABLED: TODO: type description here.
        BASIC: TODO: type description here.
        DETAILED: TODO: type description here.

    """

    DISABLED = 'disabled'

    BASIC = 'basic'

    DETAILED = 'detailed'

