# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Settings2Enum(object):

    """Implementation of the 'Settings2' enum.

    How URL patterns are applied. Can be 'network default', 'append' or
    'override'.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        APPEND: TODO: type description here.
        OVERRIDE: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    APPEND = 'append'

    OVERRIDE = 'override'

