# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class GetHelpSubtabEnum(object):

    """Implementation of the 'GetHelpSubtab' enum.

    The 'Help -> Get Help' subtab on which Cisco Meraki KB, Product Manuals,
    and Support/Case Information are displayed. Note
        that if this subtab is hidden, branding customizations for the KB on
        'Get help', Cisco Meraki product documentation,
        and support contact info will not be visible. Can be one of 'default
        or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'

