# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Protocol3Enum(object):

    """Implementation of the 'Protocol3' enum.

    The type of protocol (must be 'tcp', 'udp', or 'any').

    Attributes:
        TCP: TODO: type description here.
        UDP: TODO: type description here.
        ANY: TODO: type description here.

    """

    TCP = 'tcp'

    UDP = 'udp'

    ANY = 'any'

