# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class EncryptionModeEnum(object):

    """Implementation of the 'EncryptionMode' enum.

    The psk encryption mode for the SSID ('wep' or 'wpa'). This param is only
    valid if the authMode is 'psk'

    Attributes:
        WEP: TODO: type description here.
        WPA: TODO: type description here.

    """

    WEP = 'wep'

    WPA = 'wpa'

