# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BandSelectionTypeEnum(object):

    """Implementation of the 'BandSelectionType' enum.

    Band selection can be set to either 'ssid' or 'ap'. This param is required
    on creation.

    Attributes:
        SSID: TODO: type description here.
        AP: TODO: type description here.

    """

    SSID = 'ssid'

    AP = 'ap'

