# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BandOperationModeEnum(object):

    """Implementation of the 'BandOperationMode' enum.

    Choice between 'dual', '2.4ghz' or '5ghz'. Defaults to dual.

    Attributes:
        DUAL: TODO: type description here.
        ENUM_24GHZ: TODO: type description here.
        ENUM_5GHZ: TODO: type description here.

    """

    DUAL = 'dual'

    ENUM_24GHZ = '2.4ghz'

    ENUM_5GHZ = '5ghz'

