# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SplashAuthSettingsEnum(object):

    """Implementation of the 'SplashAuthSettings' enum.

    Whether clients bound to your policy will bypass splash authorization or
    behave according to the network's rules. Can be one of 'network default'
    or 'bypass'. Only available if your network has a wireless configuration.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        BYPASS: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    BYPASS = 'bypass'

