# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UniversalSearchKnowledgeBaseSearchEnum(object):

    """Implementation of the 'UniversalSearchKnowledgeBaseSearch' enum.

    The universal search box always visible on Dashboard will, by default,
    present results from the Meraki KB. This configures
        whether these Meraki KB results should be returned. Can be one of
        'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'

