# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UdldEnum(object):

    """Implementation of the 'Udld' enum.

    The action to take when Unidirectional Link is detected (Alert only,
    Enforce). Default configuration is Alert only.

    Attributes:
        ENUM_ALERT ONLY: TODO: type description here.
        ENFORCE: TODO: type description here.

    """

    ENUM_ALERT_ONLY = 'Alert only'

    ENFORCE = 'Enforce'

