# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RadiusFailoverPolicyEnum(object):

    """Implementation of the 'RadiusFailoverPolicy' enum.

    This policy determines how authentication requests should be handled in
    the event that all of the configured RADIUS servers are unreachable ('Deny
    access' or 'Allow access')

    Attributes:
        ENUM_DENY ACCESS: TODO: type description here.
        ENUM_ALLOW ACCESS: TODO: type description here.

    """

    ENUM_DENY_ACCESS = 'Deny access'

    ENUM_ALLOW_ACCESS = 'Allow access'

