# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class OrgAccessEnum(object):

    """Implementation of the 'OrgAccess' enum.

    The privilege of the dashboard administrator on the organization. Can be
    one of 'full', 'read-only', 'enterprise' or 'none'

    Attributes:
        FULL: TODO: type description here.
        READONLY: TODO: type description here.
        ENTERPRISE: TODO: type description here.
        NONE: TODO: type description here.

    """

    FULL = 'full'

    READONLY = 'read-only'

    ENTERPRISE = 'enterprise'

    NONE = 'none'

