# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ObjectTypeEnum(object):

    """Implementation of the 'objectType' enum.

    TODO: type enum description here.

    Attributes:
        PERSON: TODO: type description here.
        VEHICLE: TODO: type description here.

    """

    PERSON = 'person'

    VEHICLE = 'vehicle'

