# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AuthModeEnum(object):

    """Implementation of the 'AuthMode' enum.

    The association control method for the SSID ('open', 'psk',
    'open-with-radius', '8021x-meraki' or '8021x-radius')

    Attributes:
        OPEN: TODO: type description here.
        PSK: TODO: type description here.
        OPENWITHRADIUS: TODO: type description here.
        ENUM_8021XMERAKI: TODO: type description here.
        ENUM_8021XRADIUS: TODO: type description here.

    """

    OPEN = 'open'

    PSK = 'psk'

    OPENWITHRADIUS = 'open-with-radius'

    ENUM_8021XMERAKI = '8021x-meraki'

    ENUM_8021XRADIUS = '8021x-radius'

