# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DhcpLeaseTimeEnum(object):

    """Implementation of the 'DhcpLeaseTime' enum.

    The term of DHCP leases if the appliance is running a DHCP server on this
    VLAN. One of: '30 minutes', '1 hour', '4 hours', '12 hours', '1 day' or '1
    week'

    Attributes:
        ENUM_30 MINUTES: TODO: type description here.
        ENUM_1 HOUR: TODO: type description here.
        ENUM_4 HOURS: TODO: type description here.
        ENUM_12 HOURS: TODO: type description here.
        ENUM_1 DAY: TODO: type description here.
        ENUM_1 WEEK: TODO: type description here.

    """

    ENUM_30_MINUTES = '30 minutes'

    ENUM_1_HOUR = '1 hour'

    ENUM_4_HOURS = '4 hours'

    ENUM_12_HOURS = '12 hours'

    ENUM_1_DAY = '1 day'

    ENUM_1_WEEK = '1 week'

