# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class V3PrivModeEnum(object):

    """Implementation of the 'V3PrivMode' enum.

    The SNMP version 3 privacy mode. Can be either 'DES' or 'AES128'.

    Attributes:
        DES: TODO: type description here.
        AES128: TODO: type description here.

    """

    DES = 'DES'

    AES128 = 'AES128'

