# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DhcpHandlingEnum(object):

    """Implementation of the 'DhcpHandling' enum.

    The appliance's handling of DHCP requests on this VLAN. One of: 'Run a
    DHCP server', 'Relay DHCP to another server' or 'Do not respond to DHCP
    requests'

    Attributes:
        ENUM_RUN A DHCP SERVER: TODO: type description here.
        ENUM_RELAY DHCP TO ANOTHER SERVER: TODO: type description here.
        ENUM_DO NOT RESPOND TO DHCP REQUESTS: TODO: type description here.

    """

    ENUM_RUN_A_DHCP_SERVER = 'Run a DHCP server'

    ENUM_RELAY_DHCP_TO_ANOTHER_SERVER = 'Relay DHCP to another server'

    ENUM_DO_NOT_RESPOND_TO_DHCP_REQUESTS = 'Do not respond to DHCP requests'

