# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class HelpTabEnum(object):

    """Implementation of the 'HelpTab' enum.

    The Help tab, under which all support information resides. If this tab is
    hidden, no other 'Help' branding
        customizations will be visible. Can be one of 'default or inherit',
        'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'

