__all__ = [
    'base_controller',
    'api_usage_controller',
    'action_batches_controller',
    'admins_controller',
    'alert_settings_controller',
    'bluetooth_clients_controller',
    'cameras_controller',
    'clients_controller',
    'config_templates_controller',
    'connectivity_monitoring_destinations_controller',
    'content_filtering_categories_controller',
    'content_filtering_rules_controller',
    'dashboard_branding_policies_controller',
    'devices_controller',
    'events_controller',
    'firewalled_services_controller',
    'floorplans_controller',
    'group_policies_controller',
    'http_servers_controller',
    'intrusion_settings_controller',
    'licenses_controller',
    'mrl_3_firewall_controller',
    'mv_sense_controller',
    'mx_11_nat_rules_controller',
    'mx_1_many_nat_rules_controller',
    'mxl_3_firewall_controller',
    'mxl_7_application_categories_controller',
    'mxl_7_firewall_controller',
    'mxvlan_ports_controller',
    'mxvpn_firewall_controller',
    'mx_cellular_firewall_controller',
    'mx_port_forwarding_rules_controller',
    'mx_static_routes_controller',
    'mx_warm_spare_settings_controller',
    'malware_settings_controller',
    'management_interface_settings_controller',
    'meraki_auth_users_controller',
    'named_tag_scope_controller',
    'net_flow_settings_controller',
    'networks_controller',
    'open_api_spec_controller',
    'organizations_controller',
    'pii_controller',
    'radio_settings_controller',
    'saml_roles_controller',
    'sm_controller',
    'snmp_settings_controller',
    'ssi_ds_controller',
    'security_events_controller',
    'splash_login_attempts_controller',
    'splash_settings_controller',
    'switch_ac_ls_controller',
    'switch_port_schedules_controller',
    'switch_ports_controller',
    'switch_profiles_controller',
    'switch_settings_controller',
    'switch_stacks_controller',
    'syslog_servers_controller',
    'traffic_analysis_settings_controller',
    'traffic_shaping_controller',
    'uplink_settings_controller',
    'vla_ns_controller',
    'webhook_logs_controller',
    'wireless_health_controller',
    'wireless_settings_controller',
]