# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class IpVersionEnum(object):

    """Implementation of the 'IpVersion' enum.

    IP address version (must be 'any', 'ipv4' or 'ipv6'). Applicable only if
    network supports IPv6. Default value is 'ipv4'.

    Attributes:
        ANY: TODO: type description here.
        IPV4: TODO: type description here.
        IPV6: TODO: type description here.

    """

    ANY = 'any'

    IPV4 = 'ipv4'

    IPV6 = 'ipv6'

