# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkWirelessSettings(object):

    """Implementation of the 'updateNetworkWirelessSettings' model.

    TODO: type model description here.

    Attributes:
        meshing_enabled (bool): Toggle for enabling or disabling meshing in a
            network
        ipv_6_bridge_enabled (bool): Toggle for enabling or disabling IPv6
            bridging in a network (Note: if enabled, SSIDs must also be
            configured to use bridge mode)
        location_analytics_enabled (bool): Toggle for enabling or disabling
            location analytics for your network

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "meshing_enabled":'meshingEnabled',
        "ipv_6_bridge_enabled":'ipv6BridgeEnabled',
        "location_analytics_enabled":'locationAnalyticsEnabled'
    }

    def __init__(self,
                 meshing_enabled=None,
                 ipv_6_bridge_enabled=None,
                 location_analytics_enabled=None):
        """Constructor for the UpdateNetworkWirelessSettings class"""

        # Initialize members of the class
        self.meshing_enabled = meshing_enabled
        self.ipv_6_bridge_enabled = ipv_6_bridge_enabled
        self.location_analytics_enabled = location_analytics_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        meshing_enabled = dictionary.get('meshingEnabled')
        ipv_6_bridge_enabled = dictionary.get('ipv6BridgeEnabled')
        location_analytics_enabled = dictionary.get('locationAnalyticsEnabled')

        # Return an object of this model
        return cls(meshing_enabled,
                   ipv_6_bridge_enabled,
                   location_analytics_enabled)


