# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Policy6Enum(object):

    """Implementation of the 'Policy6' enum.

    'allow' or 'deny' traffic specified by this rule.

    Attributes:
        ALLOW: TODO: type description here.
        DENY: TODO: type description here.

    """

    ALLOW = 'allow'

    DENY = 'deny'

