__all__ = [
    'update_device_switch_port',
    'update_network',
    'update_network_alert_settings',
    'default_destinations',
    'alert',
    'update_network_appliance_port',
    'bind_network',
    'update_network_bluetooth_settings',
    'generate_network_camera_snapshot',
    'update_network_cellular_firewall_rules',
    'rule',
    'provision_network_clients',
    'update_network_client_policy',
    'update_network_client_splash_authorization_status',
    'ssids',
    'update_network_connectivity_monitoring_destinations',
    'destination',
    'update_network_content_filtering',
    'claim_network_devices',
    'update_network_device',
    'blink_network_device_leds',
    'update_network_device_management_interface_settings',
    'wan_1',
    'wan_2',
    'update_network_device_wireless_radio_settings',
    'update_network_firewalled_service',
    'create_network_floor_plan',
    'center',
    'bottom_left_corner',
    'bottom_right_corner',
    'top_left_corner',
    'top_right_corner',
    'update_network_floor_plan',
    'center_1',
    'create_network_group_policy',
    'scheduling',
    'monday',
    'tuesday',
    'wednesday',
    'thursday',
    'friday',
    'saturday',
    'sunday',
    'bandwidth',
    'bandwidth_limits',
    'firewall_and_traffic_shaping',
    'traffic_shaping_rule',
    'definition',
    'per_client_bandwidth_limits',
    'bandwidth_limits_1',
    'l_3_firewall_rule',
    'l_7_firewall_rule',
    'content_filtering',
    'allowed_url_patterns',
    'blocked_url_patterns',
    'blocked_url_categories',
    'vlan_tagging',
    'bonjour_forwarding',
    'rule_1',
    'update_network_group_policy',
    'create_network_http_server',
    'create_network_http_servers_webhook_test',
    'update_network_http_server',
    'update_network_l_3_firewall_rules',
    'update_network_l_7_firewall_rules',
    'rule_4',
    'update_network_netflow_settings',
    'update_network_one_to_many_nat_rules',
    'rule_5',
    'update_network_one_to_one_nat_rules',
    'rule_6',
    'create_network_pii_request',
    'update_network_port_forwarding_rules',
    'rule_7',
    'update_network_security_intrusion_settings',
    'protected_networks',
    'update_network_security_malware_settings',
    'allowed_url',
    'allowed_file',
    'update_network_site_to_site_vpn',
    'hub',
    'subnet',
    'create_network_sm_app_polaris',
    'update_network_sm_app_polaris',
    'create_network_sm_bypass_activation_lock_attempt',
    'update_network_sm_device_fields',
    'device_fields',
    'wipe_network_sm_device',
    'checkin_network_sm_devices',
    'move_network_sm_devices',
    'update_network_sm_devices_tags',
    'create_network_sm_profile_clarity',
    'vendor_config',
    'update_network_sm_profile_clarity',
    'add_network_sm_profile_clarity',
    'create_network_sm_profile_umbrella',
    'provider_configuration',
    'update_network_sm_profile_umbrella',
    'add_network_sm_profile_umbrella',
    'create_network_sm_target_group',
    'update_network_sm_target_group',
    'update_network_snmp_settings',
    'user',
    'update_network_ssid',
    'radius_server',
    'radius_accounting_server',
    'ap_tags_and_vlan_id',
    'update_network_ssid_l_3_firewall_rules',
    'rule_8',
    'update_network_ssid_splash_settings',
    'update_network_ssid_traffic_shaping',
    'rule_9',
    'create_network_static_route',
    'update_network_static_route',
    'update_network_switch_access_control_lists',
    'rule_10',
    'create_network_switch_port_schedule',
    'port_schedule',
    'update_network_switch_port_schedule',
    'update_network_switch_settings',
    'power_exception',
    'update_network_switch_settings_dhcp_server_policy',
    'update_network_switch_settings_dscp_to_cos_mappings',
    'mapping',
    'update_network_switch_settings_mtu',
    'override',
    'create_network_switch_settings_qos_rule',
    'update_network_switch_settings_qos_rules_order',
    'update_network_switch_settings_qos_rule',
    'update_network_switch_settings_storm_control',
    'update_network_switch_settings_stp',
    'stp_bridge_priority',
    'create_network_switch_stack',
    'add_network_switch_stack',
    'remove_network_switch_stack',
    'update_network_syslog_servers',
    'server',
    'update_network_traffic_analysis_settings',
    'custom_pie_chart_item',
    'update_network_traffic_shaping',
    'rule_11',
    'update_network_uplink_settings',
    'bandwidth_limits_6',
    'wan_11',
    'wan_21',
    'cellular',
    'create_network_vlan',
    'update_network_vlan',
    'reserved_ip_range',
    'dhcp_option',
    'update_network_vlans_enabled_state',
    'update_network_warm_spare_settings',
    'create_network_wireless_rf_profile',
    'ap_band_settings',
    'two_four_ghz_settings',
    'five_ghz_settings',
    'update_network_wireless_rf_profile',
    'ap_band_settings_1',
    'two_four_ghz_settings_1',
    'five_ghz_settings_1',
    'update_network_wireless_settings',
    'lock_network_sm_devices',
    'create_organization',
    'update_organization',
    'create_organization_action_batch',
    'action',
    'update_organization_action_batch',
    'create_organization_admin',
    'tag',
    'network',
    'update_organization_admin',
    'create_organization_branding_policy',
    'admin_settings',
    'help_settings',
    'update_organization_branding_policies_priorities',
    'update_organization_branding_policy',
    'help_settings_1',
    'claim_organization',
    'license',
    'clone_organization',
    'assign_organization_licenses_seats',
    'move_organization_licenses',
    'move_organization_licenses_seats',
    'renew_organization_licenses_seats',
    'update_organization_license',
    'create_organization_network',
    'combine_organization_networks',
    'create_organization_saml_role',
    'tag_2',
    'network_2',
    'update_organization_saml_role',
    'update_organization_security_intrusion_settings',
    'whitelisted_rule',
    'update_organization_snmp',
    'update_organization_third_party_vpn_peers',
    'peer',
    'ipsec_policies',
    'update_organization_vpn_firewall_rules',
    'rule_12',
    'object_type_enum',
    'udld_enum',
    'major_minor_assignment_mode_enum',
    'policy_enum',
    'protocol_enum',
    'uplink_enum',
    'wan_enabled_enum',
    'access_enum',
    'settings_enum',
    'settings_1_enum',
    'type_enum',
    'policy_1_enum',
    'type_1_enum',
    'settings_2_enum',
    'settings_4_enum',
    'splash_auth_settings_enum',
    'settings_5_enum',
    'settings_6_enum',
    'service_enum',
    'policy_4_enum',
    'type_4_enum',
    'type_5_enum',
    'mode_enum',
    'access_1_enum',
    'ssid_number_enum',
    'auth_mode_enum',
    'enterprise_admin_access_enum',
    'encryption_mode_enum',
    'wpa_encryption_mode_enum',
    'splash_page_enum',
    'radius_failover_policy_enum',
    'radius_load_balancing_policy_enum',
    'policy_6_enum',
    'ip_version_enum',
    'protocol_3_enum',
    'power_type_enum',
    'default_policy_enum',
    'protocol_4_enum',
    'protocol_5_enum',
    'mode_1_enum',
    'type_7_enum',
    'dhcp_handling_enum',
    'dhcp_lease_time_enum',
    'type_9_enum',
    'min_bitrate_type_enum',
    'band_selection_type_enum',
    'band_operation_mode_enum',
    'min_bitrate_type_1_enum',
    'band_selection_type_1_enum',
    'band_operation_mode_1_enum',
    'org_access_enum',
    'applies_to_enum',
    'help_tab_enum',
    'get_help_subtab_enum',
    'community_subtab_enum',
    'cases_subtab_enum',
    'data_protection_requests_subtab_enum',
    'universal_search_knowledge_base_search_enum',
    'new_features_subtab_enum',
    'firewall_info_subtab_enum',
    'api_docs_subtab_enum',
    'hardware_replacements_subtab_enum',
    'sm_forums_enum',
    'mode_2_enum',
    'state_enum',
    'v_3_auth_mode_enum',
    'v_3_priv_mode_enum',
]