# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Policy4Enum(object):

    """Implementation of the 'Policy4' enum.

    'Deny' traffic specified by this rule

    Attributes:
        DENY: TODO: type description here.

    """

    DENY = 'deny'

