# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DefaultPolicyEnum(object):

    """Implementation of the 'DefaultPolicy' enum.

    'allow' or 'block' new DHCP servers. Default value is 'allow'.

    Attributes:
        ALLOW: TODO: type description here.
        BLOCK: TODO: type description here.

    """

    ALLOW = 'allow'

    BLOCK = 'block'

