# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class StateEnum(object):

    """Implementation of the 'state' enum.

    TODO: type enum description here.

    Attributes:
        ACTIVE: TODO: type description here.
        EXPIRED: TODO: type description here.
        EXPIRING: TODO: type description here.
        UNUSED: TODO: type description here.
        UNUSEDACTIVE: TODO: type description here.
        RECENTLYQUEUED: TODO: type description here.

    """

    ACTIVE = 'active'

    EXPIRED = 'expired'

    EXPIRING = 'expiring'

    UNUSED = 'unused'

    UNUSEDACTIVE = 'unusedActive'

    RECENTLYQUEUED = 'recentlyQueued'

