# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SmForumsEnum(object):

    """Implementation of the 'SmForums' enum.

    The 'SM Forums' subtab which links to community-based support for Cisco
    Meraki Systems Manager. Only configurable for
        organizations that contain Systems Manager networks. Can be one of
        'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'

