# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class EnterpriseAdminAccessEnum(object):

    """Implementation of the 'EnterpriseAdminAccess' enum.

    Whether or not an SSID is accessible by 'enterprise' administrators
    ('access disabled' or 'access enabled')

    Attributes:
        ENUM_ACCESS DISABLED: TODO: type description here.
        ENUM_ACCESS ENABLED: TODO: type description here.

    """

    ENUM_ACCESS_DISABLED = 'access disabled'

    ENUM_ACCESS_ENABLED = 'access enabled'

