# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DataProtectionRequestsSubtabEnum(object):

    """Implementation of the 'DataProtectionRequestsSubtab' enum.

    The 'Help -> Data protection requests' Dashboard subtab on which requests
    to delete, restrict, or export end-user data can
        be audited. Can be one of 'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'

