# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SplashPageEnum(object):

    """Implementation of the 'SplashPage' enum.

    The type of splash page for the SSID ('None', 'Click-through splash page',
    'Billing', 'Password-protected with Meraki RADIUS', 'Password-protected
    with custom RADIUS', 'Password-protected with Active Directory',
    'Password-protected with LDAP', 'SMS authentication', 'Systems Manager
    Sentry', 'Facebook Wi-Fi', 'Google OAuth' or 'Sponsored guest'). This
    attribute is not supported for template children.

    Attributes:
        NONE: TODO: type description here.
        ENUM_CLICKTHROUGH SPLASH PAGE: TODO: type description here.
        BILLING: TODO: type description here.
        ENUM_PASSWORDPROTECTED WITH MERAKI RADIUS: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH CUSTOM RADIUS: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH ACTIVE DIRECTORY: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH LDAP: TODO: type description here.
        ENUM_SMS AUTHENTICATION: TODO: type description here.
        ENUM_SYSTEMS MANAGER SENTRY: TODO: type description here.
        ENUM_FACEBOOK WIFI: TODO: type description here.
        ENUM_GOOGLE OAUTH: TODO: type description here.
        ENUM_SPONSORED GUEST: TODO: type description here.

    """

    ENUM_NONE = 'None'

    ENUM_CLICKTHROUGH_SPLASH_PAGE = 'Click-through splash page'

    BILLING = 'Billing'

    ENUM_PASSWORDPROTECTED_WITH_MERAKI_RADIUS = 'Password-protected with Meraki RADIUS'

    ENUM_PASSWORDPROTECTED_WITH_CUSTOM_RADIUS = 'Password-protected with custom RADIUS'

    ENUM_PASSWORDPROTECTED_WITH_ACTIVE_DIRECTORY = 'Password-protected with Active Directory'

    ENUM_PASSWORDPROTECTED_WITH_LDAP = 'Password-protected with LDAP'

    ENUM_SMS_AUTHENTICATION = 'SMS authentication'

    ENUM_SYSTEMS_MANAGER_SENTRY = 'Systems Manager Sentry'

    ENUM_FACEBOOK_WIFI = 'Facebook Wi-Fi'

    ENUM_GOOGLE_OAUTH = 'Google OAuth'

    ENUM_SPONSORED_GUEST = 'Sponsored guest'

